@@ -23,7 +23,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 // Qt
 
-// KDE
+// KF
 #include <KConfigDialog>
 
 // Local
@@ -48,6 +48,7 @@ private:
     InvisibleButtonGroup* mAlphaBackgroundModeGroup = nullptr;
     InvisibleButtonGroup* mWheelBehaviorGroup = nullptr;
     InvisibleButtonGroup* mAnimationMethodGroup = nullptr;
+    InvisibleButtonGroup* mFullScreenBackgroundGroup = nullptr;
     InvisibleButtonGroup* mThumbnailActionsGroup = nullptr;
     InvisibleButtonGroup* mZoomModeGroup = nullptr;
     InvisibleButtonGroup* mThumbnailBarOrientationGroup = nullptr;
