@@ -18,9 +18,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 */
 #include "mainwindow.h"
-#include "gwenview_app_debug.h"
 #include <config-gwenview.h>
-#include "dialogguard.h"
 
 // Qt
 #include <QApplication>
@@ -31,6 +29,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <QShortcut>
 #include <QSplitter>
 #include <QStackedWidget>
+#include <QFileDialog>
 #include <QTimer>
 #include <QUndoGroup>
 #include <QVBoxLayout>
@@ -43,10 +42,9 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <QJsonArray>
 #include <QJsonObject>
 
-// KDE
+// KF
 #include <KActionCategory>
 #include <KActionCollection>
-#include <QFileDialog>
 #include <KFileItem>
 #include <KLocalizedString>
 #include <KMessageBox>
@@ -69,6 +67,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #endif
 
 // Local
+#include "gwenview_app_debug.h"
+#include "dialogguard.h"
 #include "configdialog.h"
 #include "documentinfoprovider.h"
 #include "viewmainpage.h"
@@ -411,7 +411,7 @@ struct MainWindow::Private
         
         QAction * replaceLocationAction = actionCollection->addAction(QStringLiteral("replace_location"));
         replaceLocationAction->setText(i18nc("@action:inmenu Navigation Bar", "Replace Location"));
-        actionCollection->setDefaultShortcut(replaceLocationAction, Qt::CTRL + Qt::Key_L);
+        actionCollection->setDefaultShortcut(replaceLocationAction, Qt::CTRL | Qt::Key_L);
         connect(replaceLocationAction, &QAction::triggered, q, &MainWindow::replaceLocation);
 
         mBrowseAction = view->addAction("browse");
@@ -1037,7 +1037,7 @@ void MainWindow::setActiveViewModeAction(QAction* action)
             // his image back.
             d->mViewMainPage->reset();
         }
-        setCaption(QString());
+        setCaption(d->mUrlNavigator->locationUrl().adjusted(QUrl::RemoveScheme).toString());
     }
     d->autoAssignThumbnailProvider();
     toggleSideBar(d->sideBarVisibility()); 
@@ -1287,6 +1287,9 @@ void MainWindow::slotCurrentDirUrlChanged(const QUrl &url)
     if (url.isValid()) {
         d->mUrlNavigator->setLocationUrl(url);
         d->mGoUpAction->setEnabled(url.path() != "/");
+        if (d->mCurrentMainPageId == BrowseMainPageId) {
+            setCaption(d->mUrlNavigator->locationUrl().adjusted(QUrl::RemoveScheme).toString());
+        }
     } else {
         d->mGoUpAction->setEnabled(false);
     }
