@@ -25,20 +25,26 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <QApplication>
 #include <QDate>
 #include <QStackedWidget>
+#include <QStandardPaths>
 
-// KDE
-#include "gwenview_importer_debug.h"
+// KF
+#include <kio_version.h>
 #include <KIO/DeleteJob>
 #include <KMessageBox>
 #include <KProtocolInfo>
-#include <KRun>
 #include <KService>
 #include <KStandardGuiItem>
 #include <Solid/Device>
-#include <QStandardPaths>
 #include <KLocalizedString>
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 71, 0)
+#include <KIO/ApplicationLauncherJob>
+#include <KIO/JobUiDelegate>
+#else
+#include <KRun>
+#endif
 
 // Local
+#include "gwenview_importer_debug.h"
 #include "dialogpage.h"
 #include "importer.h"
 #include "importerconfig.h"
@@ -165,7 +171,14 @@ public:
         if (!service) {
             qCCritical(GWENVIEW_IMPORTER_LOG) << "Could not find gwenview";
         } else {
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 71, 0)
+            auto *job = new KIO::ApplicationLauncherJob(service);
+            job->setUrls({mThumbnailPage->destinationUrl()});
+            job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, nullptr));
+            job->start();
+#else
             KRun::runService(*service, {mThumbnailPage->destinationUrl()}, nullptr /* window */);
+#endif
         }
     }
 
