@@ -25,7 +25,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <QStringList>
 #include <QVariant>
 
-// KDE
+// KF
 
 // Local
 
@@ -38,6 +38,13 @@ TagSet::TagSet()
 TagSet::TagSet(const QSet<SemanticInfoTag>& set)
 : QSet<QString>(set) {}
 
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+TagSet::TagSet(const QList<SemanticInfoTag>& list)
+: QSet(list.begin(), list.end())
+{
+}
+#endif
+
 QVariant TagSet::toVariant() const
 {
     QStringList lst = values();
@@ -50,6 +57,15 @@ TagSet TagSet::fromVariant(const QVariant& variant)
     return TagSet::fromList(lst);
 }
 
+TagSet TagSet::fromList(const QList<SemanticInfoTag>& list)
+{
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+    return TagSet(list);
+#else
+    return QSet<SemanticInfoTag>::fromList(lst);
+#endif
+}
+
 AbstractSemanticInfoBackEnd::AbstractSemanticInfoBackEnd(QObject* parent)
 : QObject(parent)
 {
