@@ -24,10 +24,10 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 // Qt
 #include <QListView>
-
-// KDE
 #include <QUrl>
 
+// KF
+
 class KFileItem;
 class QDragEnterEvent;
 class QDragMoveEvent;
@@ -123,7 +123,6 @@ Q_SIGNALS:
      * signal replaces it.
      */
     void indexActivated(const QModelIndex&);
-    void urlListDropped(const QList<QUrl>& lst, const QUrl &destination);
 
     void thumbnailSizeChanged(const QSize&);
     void thumbnailWidthChanged(int);
