@@ -25,7 +25,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <QGesture>
 #include <QGestureRecognizer>
 
-// KDE
+// KF
 
 // Local
 
@@ -37,7 +37,7 @@ class GWENVIEWLIB_EXPORT TwoFingerTap : public QGesture
 {
 
 public:
-    explicit TwoFingerTap(QObject* parent = 0);
+    explicit TwoFingerTap(QObject* parent = nullptr);
 
 private:
 };
