@@ -26,7 +26,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 // Qt
 #include <QFrame>
 
-// KDE
+// KF
 
 // Local
 
@@ -56,6 +56,7 @@ Q_SIGNALS:
 
 private Q_SLOTS:
     void slotZoomSliderActionTriggered();
+    void setCustomZoomFromSpinBox(qreal zoom);
 
 private:
     friend struct ZoomWidgetPrivate;
