@@ -23,11 +23,13 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 // libc
 #include <utime.h>
 
-// KDE
-#include <KFileItem>
+// Qt
 #include <QTemporaryFile>
 #include <QTest>
 
+// KF
+#include <KFileItem>
+
 // Local
 #include "../lib/timeutils.h"
 
@@ -39,7 +41,7 @@ using namespace Gwenview;
 
 static void touchFile(const QString& path)
 {
-    utime(QFile::encodeName(path).data(), 0);
+    utime(QFile::encodeName(path).data(), nullptr);
 }
 
 #define NEW_ROW(fileName, dateTime) QTest::newRow(fileName) << fileName << dateTime
